# glucose-stats - Calculate glucose statistics from continuous glucose monitoring data

## Installation
The package is available under pypi:
```
pip install glucose-stats
```

## Usage
This package is currently under construction. More info will come soon!

If you are running into problems, feel welcome to contact the author (evanweenen@ethz.ch).

## License
This code is &copy; E. van Weenen, 2023, and it is made available under the MIT license enclosed with the software.

Over and above the legal restrictions imposed by this license, if you use this software for an academic publication then you are obliged to provide proper attribution. 
```
E. van Weenen. glucose-stats: Calculate glucose statistics from continuous glucose monitoring data, v0.0.1 (2023). github.com/evavanweenen/glucose-stats.
```